==> igniteui-react-core-18.2.0-beta.2.tgz: package/esm2015/lib/HeatTileGeneratorDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { HeatTileGeneratorDescription } from "./HeatTileGeneratorDescription";
/**
 * @hidden
 */
export let HeatTileGeneratorDescriptionMetadata = /*@__PURE__*/ (() => {
    class HeatTileGeneratorDescriptionMetadata extends Base {
        static b(a) {
            if (HeatTileGeneratorDescriptionMetadata.a == null) {
                HeatTileGeneratorDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                HeatTileGeneratorDescriptionMetadata.c(HeatTileGeneratorDescriptionMetadata.a);
            }
            if (a.k(HeatTileGeneratorDescriptionMetadata.a)) {
                return;
            }
            a.ab(HeatTileGeneratorDescriptionMetadata.a);
        }
        static c(a) {
            a.item("YValues", "Array:double");
            a.item("XValues", "Array:double");
            a.item("Values", "Array:double");
            a.item("MinimumColor", "Color");
            a.item("MaximumColor", "Color");
            a.item("ScaleColors", "Array:string:Color");
            a.item("ScaleColorOffsets", "Array:double");
            a.item("BlurRadius", "Number:double");
            a.item("MaxBlurRadius", "Number:double");
            a.item("UseBlurRadiusAdjustedForZoom", "Boolean");
            a.item("UseGlobalMinMax", "Boolean");
            a.item("UseGlobalMinMaxAdjustedForZoom", "Boolean");
            a.item("MinimumValue", "Number:double");
            a.item("MaximumValue", "Number:double");
            a.item("LogarithmBase", "Number:double");
            a.item("UseLogarithmicScale", "Boolean");
            a.item("UseWebWorkers", "Boolean");
            a.item("WebWorkerScriptPath", "String");
            a.item("WebWorkerInstanceRef", "(w:WebWorkerInstance,wf:WebWorkerInstance)DataRef");
        }
        static d(a) {
            HeatTileGeneratorDescriptionMetadata.b(a);
            a.ad("HeatTileGenerator", () => new HeatTileGeneratorDescription());
            a.ac("HeatTileGenerator", HeatTileGeneratorDescriptionMetadata.a);
        }
    }
    HeatTileGeneratorDescriptionMetadata.$t = /*@__PURE__*/ markType(HeatTileGeneratorDescriptionMetadata, 'HeatTileGeneratorDescriptionMetadata');
    HeatTileGeneratorDescriptionMetadata.a = null;
    return HeatTileGeneratorDescriptionMetadata;
})();

==> igniteui-react-core-18.7.5-beta.2.tgz: package/esm2015/lib/HeatTileGeneratorDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { HeatTileGeneratorDescription } from "./HeatTileGeneratorDescription";
/**
 * @hidden
 */
export let HeatTileGeneratorDescriptionMetadata = /*@__PURE__*/ (() => {
    class HeatTileGeneratorDescriptionMetadata extends Base {
        static b(a) {
            if (HeatTileGeneratorDescriptionMetadata.a == null) {
                HeatTileGeneratorDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                HeatTileGeneratorDescriptionMetadata.c(HeatTileGeneratorDescriptionMetadata.a);
            }
            if (a.k(HeatTileGeneratorDescriptionMetadata.a)) {
                return;
            }
            a.ac(HeatTileGeneratorDescriptionMetadata.a);
        }
        static c(a) {
            a.item("YValues", "Array:double");
            a.item("XValues", "Array:double");
            a.item("Values", "Array:double");
            a.item("MinimumColor", "Color");
            a.item("MaximumColor", "Color");
            a.item("ScaleColors", "Array:string:Color");
            a.item("ScaleColorOffsets", "Array:double");
            a.item("BlurRadius", "Number:double");
            a.item("MaxBlurRadius", "Number:double");
            a.item("UseBlurRadiusAdjustedForZoom", "Boolean");
            a.item("UseGlobalMinMax", "Boolean");
            a.item("UseGlobalMinMaxAdjustedForZoom", "Boolean");
            a.item("MinimumValue", "Number:double");
            a.item("MaximumValue", "Number:double");
            a.item("LogarithmBase", "Number:double");
            a.item("UseLogarithmicScale", "Boolean");
            a.item("UseWebWorkers", "Boolean");
            a.item("WebWorkerScriptPath", "String");
            a.item("WebWorkerInstanceRef", "(w:WebWorkerInstance,wf:WebWorkerInstance)DataRef");
        }
        static d(a) {
            HeatTileGeneratorDescriptionMetadata.b(a);
            a.ae("HeatTileGenerator", () => new HeatTileGeneratorDescription());
            a.ad("HeatTileGenerator", HeatTileGeneratorDescriptionMetadata.a);
        }
    }
    HeatTileGeneratorDescriptionMetadata.$t = /*@__PURE__*/ markType(HeatTileGeneratorDescriptionMetadata, 'HeatTileGeneratorDescriptionMetadata');
    HeatTileGeneratorDescriptionMetadata.a = null;
    return HeatTileGeneratorDescriptionMetadata;
})();
